/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*             UNIDAD DE EVALUACIN DEL SISTEMA EDUCATIVO NACIONAL
/*             DIRECCIN GENERAL DE MEDICIN Y TRATAMIENTO DE DATOS
/*
/*                      DIRECCIN DE TRATAMIENTO DE DATOS
/*
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                     TERCER GRADO DE PRIMARIA (Excale 03)
/*
/*                            **** MATEMTICAS ****
/*
/*                     Ciclo escolar evaluado: 2013 - 2014
/*_____________________________________________________________________________
/*
/*
/*            SINTAXIS PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE
/*                         MATEMTICAS EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale03_2014_Alum_Mat.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale03_2014_Alum_Mat.txt
/*         as como el archivo Excale03_2014_Alum_Mat.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale03_2014_Alum_Mat.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale03_2014_Alum_Mat.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Direccin de Tratamiento de Datos
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 32025
/*      Domicilio: Av. Barranca del Muerto no. 341, 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 01 DE SEPTIEMBRE 2015
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale03_2014_Alum_Mat.TXT";

PROC FORMAT;
     VALUE id_entF     1         =  "Aguascalientes"
                       2         =  "Baja California"
                       3         =  "Baja California Sur"
                       4         =  "Campeche"
                       5         =  "Coahuila"
                       6         =  "Colima"
                       7         =  "Chiapas"
                       8         =  "Chihuahua"
                       9         =  "Distrito Federal"
                       10        =  "Durango"
                       11        =  "Guanajuato"
                       12        =  "Guerrero"
                       13        =  "Hidalgo"
                       14        =  "Jalisco"
                       15        =  "Mxico"
                       16        =  "Michoacn"
                       17        =  "Morelos"
                       18        =  "Nayarit"
                       19        =  "Nuevo Len"
                       20        =  "Oaxaca"
                       21        =  "Puebla"
                       22        =  "Quertaro"
                       23        =  "Quintana Roo"
                       24        =  "San Luis Potos"
                       25        =  "Sinaloa"
                       26        =  "Sonora"
                       27        =  "Tabasco"
                       28        =  "Tamaulipas"
                       29        =  "Tlaxcala"
                       30        =  "Veracruz"
                       31        =  "Yucatn"
                       32        =  "Zacatecas";
     VALUE id_modF     1         =  "Urbana Pblica"
                       2         =  "Rural Pblica"
                       3         =  "Educacin Indgena"
                       4         =  "Curso Comunitario"
                       5         =  "Privada"
                       6         =  "General"
                       7         =  "Tcnica"
                       8         =  "Telesecundaria"
                       9         =  "Privada";
     VALUE $modF       "UP"      =  "Urbano Pblico"
                       "RP"      =  "Rural Pblico"
                       "EI"      =  "Educacin Indgena"
                       "CC"      =  "Cursos Comunitarios"
                       "UPV"     =  "Privados"
                       "GRAL"    =  "General"
                       "TEC"     =  "Tcnica"
                       "TV"      =  "Telesecundaria"
                       "PRIV"    =  "Privada";
     VALUE $entestF    "999"     =  "Respuesta omitida";
     VALUE sexoF       1         =  "Hombre"
                       2         =  "Mujer"
                       8         =  "Respuesta mltiple"
                       9         =  "Respuesta omitida";
     VALUE edad_acF    7         =  "7 aos"
                       8         =  "8 aos"
                       9         =  "9 aos"
                       10        =  "10 aos"
                       11        =  "11 aos"
                       12        =  "12 aos"
	               98        =  "Respuesta mltiple"
                       99        =  "Respuesta omitida";
     VALUE mes_nacF    1         =  "Enero"
                       2         =  "Febrero"
                       3         =  "Marzo"
                       4         =  "Abril"
                       5         =  "Mayo"
                       6         =  "Junio"
                       7         =  "Julio"
                       8         =  "Agosto"
                       9         =  "Septiembre"
                       10        =  "Octubre"
                       11        =  "Noviembre"
                       12        =  "Diciembre"
                       98        =  "Respuesta mltiple"
                       99        =  "Respuesta omitida";
     VALUE edadF       99        =  "Respuesta omitida";
     VALUE edadCF      1         =  "8 aos o menos"
                       2         =  "9 aos"
                       3         =  "10 aos"
                       4         =  "11 aos o ms"
                       9         =  "Respuesta omitida";
     VALUE edadNF      1         =  "Edad normativa"
                       2         =  "Extra-edad"
                       9         =  "Respuesta omitida";
     VALUE edadAF      0         =  "Sin edad anticipada"
                       1         =  "Edad anticipada"
                       9         =  "Respuesta omitida";
     VALUE edadEF      0         =  "Sin extra edad severa"
                       1         =  "Extra edad severa"
                       9         =  "Respuesta omitida";
     VALUE docenF      99999     =  "Respuesta omitida";
     VALUE reactF      0         =  "Fallo"
                       1         =  "Acierto"
                       5         =  "Reactivo no alcanzado (se considera como no administrado)"
                       6         =  "Reactivo no administrado por error de impresin"
                       7         =  "Reactivo no administrado (No se incluy en su cuadernillo de examen)";
     VALUE nvlF        1         =  "Por debajo del nivel bsico"
                       2         =  "Bsico"
                       3         =  "Medio"
                       4         =  "Avanzado";
     VALUE nvblF       0         =  "Por debajo del nivel bsico"
                       1         =  "Al menos el nivel bsico";
     VALUE nvmlF       0         =  "Por debajo del nivel medio"
                       1         =  "Al menos el nivel medio";
RUN;



DATA INEE.Excale03_2014_Alum_Mat;
   LENGTH
      NACIONAL         3
      ESCUELA          4
      ID_ENT           3
      NOM_ENT          $19
      ID_MOD           3
      MOD              $4
      ESTRATO          $7
      ENTEST           $6
      ALUMNO           5
      ID_INSTR         $15
      SEXO             3
      EDAD_AC          3
      MES_NAC          3
      EDAD             8
      EDAD_ACC         3
      EDAD_N           3
      EDAD_ANT         3
      EDAD_EES         3
      W_ALU            8
      DOCENTE          5
      PMA_01           3
      PMA_02           3
      PMA_03           3
      PMA_04           3
      PMA_05           3
      PMA_06           3
      PMA_07           3
      PMA_08           3
      PMA_09           3
      PMA_10           3
      PMA_11           3
      PMA_13           3
      PMB_01           3
      PMB_02           3
      PMB_03           3
      PMB_04           3
      PMB_05           3
      PMB_06           3
      PMB_07           3
      PMB_08           3
      PMB_09           3
      PMB_10           3
      PMB_11           3
      PMB_13           3
      PMC_01           3
      PMC_02           3
      PMC_04           3
      PMC_05           3
      PMC_06           3
      PMC_07           3
      PMC_08           3
      PMC_09           3
      PMC_10           3
      PMC_11           3
      PMC_12           3
      PMC_13           3
      PMD_01           3
      PMD_02           3
      PMD_03           3
      PMD_04           3
      PMD_05           3
      PMD_06           3
      PMD_07           3
      PMD_08           3
      PMD_09           3
      PMD_10           3
      PMD_11           3
      PMD_13           3
      PMD_14           3
      PME_01           3
      PME_02           3
      PME_03           3
      PME_04           3
      PME_05           3
      PME_06           3
      PME_07           3
      PME_08           3
      PME_10           3
      PME_11           3
      PME_13           3
      PMF_01           3
      PMF_02           3
      PMF_04           3
      PMF_05           3
      PMF_06           3
      PMF_07           3
      PMF_09           3
      PMF_10           3
      PMF_11           3
      PMF_12           3
      PMF_13           3
      PV1MAT           8
      PV2MAT           8
      PV3MAT           8
      PV4MAT           8
      PV5MAT           8
      MATNVL1          3
      MATNVL2          3
      MATNVL3          3
      MATNVL4          3
      MATNVL5          3
      MATNVBL1         3
      MATNVBL2         3
      MATNVBL3         3
      MATNVBL4         3
      MATNVBL5         3
      MATNVML1         3
      MATNVML2         3
      MATNVML3         3
      MATNVML4         3
      MATNVML5         3
      WVARSTRR         3
      W_FSTR1          8
      W_FSTR2          8
      W_FSTR3          8
      W_FSTR4          8
      W_FSTR5          8
      W_FSTR6          8
      W_FSTR7          8
      W_FSTR8          8
      W_FSTR9          8
      W_FSTR10         8
      W_FSTR11         8
      W_FSTR12         8
      W_FSTR13         8
      W_FSTR14         8
      W_FSTR15         8
      W_FSTR16         8
      W_FSTR17         8
      W_FSTR18         8
      W_FSTR19         8
      W_FSTR20         8
      W_FSTR21         8
      W_FSTR22         8
      W_FSTR23         8
      W_FSTR24         8
      W_FSTR25         8
      W_FSTR26         8
      W_FSTR27         8
      W_FSTR28         8
      W_FSTR29         8
      W_FSTR30         8
      W_FSTR31         8
      W_FSTR32         8
      W_FSTR33         8
      W_FSTR34         8
      W_FSTR35         8
      W_FSTR36         8
      W_FSTR37         8
      W_FSTR38         8
      W_FSTR39         8
      W_FSTR40         8
      W_FSTR41         8
      W_FSTR42         8
      W_FSTR43         8
      W_FSTR44         8
      W_FSTR45         8
      W_FSTR46         8
      W_FSTR47         8
      W_FSTR48         8
      W_FSTR49         8
      W_FSTR50         8
      W_FSTR51         8
      W_FSTR52         8
      W_FSTR53         8
      W_FSTR54         8
      W_FSTR55         8
      W_FSTR56         8
      W_FSTR57         8
      W_FSTR58         8
      W_FSTR59         8
      W_FSTR60         8
      W_FSTR61         8
      W_FSTR62         8
      W_FSTR63         8
      W_FSTR64         8
      W_FSTR65         8
      W_FSTR66         8
      W_FSTR67         8
      W_FSTR68         8
      W_FSTR69         8
      W_FSTR70         8
      W_FSTR71         8
      W_FSTR72         8
      W_FSTR73         8
      W_FSTR74         8
      W_FSTR75         8
      W_FSTR76         8
      W_FSTR77         8
      W_FSTR78         8
      W_FSTR79         8
      W_FSTR80         8
      W_FSTR81         8
      W_FSTR82         8
      W_FSTR83         8
      W_FSTR84         8
      W_FSTR85         8
      W_FSTR86         8
      W_FSTR87         8
      W_FSTR88         8
      W_FSTR89         8
      W_FSTR90         8
      W_FSTR91         8
      W_FSTR92         8
      W_FSTR93         8
      W_FSTR94         8
      W_FSTR95         8
      W_FSTR96         8
      W_FSTR97         8
      W_FSTR98         8
      W_FSTR99         8
      W_FSTR100        8
;



INFILE alum MISSOVER LINESIZE = 1330;
   INPUT
      NACIONAL          1 - 1
      ESCUELA           2 - 5
      ID_ENT            6 - 7
      NOM_ENT           8 - 27
      ID_MOD           28 - 28
      MOD              29 - 32
      ESTRATO          33 - 39
      ENTEST           40 - 45
      ALUMNO           46 - 50
      ID_INSTR         51 - 65
      SEXO             66 - 66
      EDAD_AC          67 - 68
      MES_NAC          69 - 70
      EDAD             71 - 81
      EDAD_ACC         82 - 82
      EDAD_N           83 - 83
      EDAD_ANT         84 - 84
      EDAD_EES         85 - 85
      W_ALU            86 - 96
      DOCENTE          97 - 101
      PMA_01          102 - 102
      PMA_02          103 - 103
      PMA_03          104 - 104
      PMA_04          105 - 105
      PMA_05          106 - 106
      PMA_06          107 - 107
      PMA_07          108 - 108
      PMA_08          109 - 109
      PMA_09          110 - 110
      PMA_10          111 - 111
      PMA_11          112 - 112
      PMA_13          113 - 113
      PMB_01          114 - 114
      PMB_02          115 - 115
      PMB_03          116 - 116
      PMB_04          117 - 117
      PMB_05          118 - 118
      PMB_06          119 - 119
      PMB_07          120 - 120
      PMB_08          121 - 121
      PMB_09          122 - 122
      PMB_10          123 - 123
      PMB_11          124 - 124
      PMB_13          125 - 125
      PMC_01          126 - 126
      PMC_02          127 - 127
      PMC_04          128 - 128
      PMC_05          129 - 129
      PMC_06          130 - 130
      PMC_07          131 - 131
      PMC_08          132 - 132
      PMC_09          133 - 133
      PMC_10          134 - 134
      PMC_11          135 - 135
      PMC_12          136 - 136
      PMC_13          137 - 137
      PMD_01          138 - 138
      PMD_02          139 - 139
      PMD_03          140 - 140
      PMD_04          141 - 141
      PMD_05          142 - 142
      PMD_06          143 - 143
      PMD_07          144 - 144
      PMD_08          145 - 145
      PMD_09          146 - 146
      PMD_10          147 - 147
      PMD_11          148 - 148
      PMD_13          149 - 149
      PMD_14          150 - 150
      PME_01          151 - 151
      PME_02          152 - 152
      PME_03          153 - 153
      PME_04          154 - 154
      PME_05          155 - 155
      PME_06          156 - 156
      PME_07          157 - 157
      PME_08          158 - 158
      PME_10          159 - 159
      PME_11          160 - 160
      PME_13          161 - 161
      PMF_01          162 - 162
      PMF_02          163 - 163
      PMF_04          164 - 164
      PMF_05          165 - 165
      PMF_06          166 - 166
      PMF_07          167 - 167
      PMF_09          168 - 168
      PMF_10          169 - 169
      PMF_11          170 - 170
      PMF_12          171 - 171
      PMF_13          172 - 172
      PV1MAT          173 - 180
      PV2MAT          181 - 188
      PV3MAT          189 - 196
      PV4MAT          197 - 204
      PV5MAT          205 - 212
      MATNVL1         213 - 213
      MATNVL2         214 - 214
      MATNVL3         215 - 215
      MATNVL4         216 - 216
      MATNVL5         217 - 217
      MATNVBL1        218 - 218
      MATNVBL2        219 - 219
      MATNVBL3        220 - 220
      MATNVBL4        221 - 221
      MATNVBL5        222 - 222
      MATNVML1        223 - 223
      MATNVML2        224 - 224
      MATNVML3        225 - 225
      MATNVML4        226 - 226
      MATNVML5        227 - 227
      WVARSTRR        228 - 230
      W_FSTR1         231 - 241
      W_FSTR2         242 - 252
      W_FSTR3         253 - 263
      W_FSTR4         264 - 274
      W_FSTR5         275 - 285
      W_FSTR6         286 - 296
      W_FSTR7         297 - 307
      W_FSTR8         308 - 318
      W_FSTR9         319 - 329
      W_FSTR10        330 - 340
      W_FSTR11        341 - 351
      W_FSTR12        352 - 362
      W_FSTR13        363 - 373
      W_FSTR14        374 - 384
      W_FSTR15        385 - 395
      W_FSTR16        396 - 406
      W_FSTR17        407 - 417
      W_FSTR18        418 - 428
      W_FSTR19        429 - 439
      W_FSTR20        440 - 450
      W_FSTR21        451 - 461
      W_FSTR22        462 - 472
      W_FSTR23        473 - 483
      W_FSTR24        484 - 494
      W_FSTR25        495 - 505
      W_FSTR26        506 - 516
      W_FSTR27        517 - 527
      W_FSTR28        528 - 538
      W_FSTR29        539 - 549
      W_FSTR30        550 - 560
      W_FSTR31        561 - 571
      W_FSTR32        572 - 582
      W_FSTR33        583 - 593
      W_FSTR34        594 - 604
      W_FSTR35        605 - 615
      W_FSTR36        616 - 626
      W_FSTR37        627 - 637
      W_FSTR38        638 - 648
      W_FSTR39        649 - 659
      W_FSTR40        660 - 670
      W_FSTR41        671 - 681
      W_FSTR42        682 - 692
      W_FSTR43        693 - 703
      W_FSTR44        704 - 714
      W_FSTR45        715 - 725
      W_FSTR46        726 - 736
      W_FSTR47        737 - 747
      W_FSTR48        748 - 758
      W_FSTR49        759 - 769
      W_FSTR50        770 - 780
      W_FSTR51        781 - 791
      W_FSTR52        792 - 802
      W_FSTR53        803 - 813
      W_FSTR54        814 - 824
      W_FSTR55        825 - 835
      W_FSTR56        836 - 846
      W_FSTR57        847 - 857
      W_FSTR58        858 - 868
      W_FSTR59        869 - 879
      W_FSTR60        880 - 890
      W_FSTR61        891 - 901
      W_FSTR62        902 - 912
      W_FSTR63        913 - 923
      W_FSTR64        924 - 934
      W_FSTR65        935 - 945
      W_FSTR66        946 - 956
      W_FSTR67        957 - 967
      W_FSTR68        968 - 978
      W_FSTR69        979 - 989
      W_FSTR70        990 - 1000
      W_FSTR71       1001 - 1011
      W_FSTR72       1012 - 1022
      W_FSTR73       1023 - 1033
      W_FSTR74       1034 - 1044
      W_FSTR75       1045 - 1055
      W_FSTR76       1056 - 1066
      W_FSTR77       1067 - 1077
      W_FSTR78       1078 - 1088
      W_FSTR79       1089 - 1099
      W_FSTR80       1100 - 1110
      W_FSTR81       1111 - 1121
      W_FSTR82       1122 - 1132
      W_FSTR83       1133 - 1143
      W_FSTR84       1144 - 1154
      W_FSTR85       1155 - 1165
      W_FSTR86       1166 - 1176
      W_FSTR87       1177 - 1187
      W_FSTR88       1188 - 1198
      W_FSTR89       1199 - 1209
      W_FSTR90       1210 - 1220
      W_FSTR91       1221 - 1231
      W_FSTR92       1232 - 1242
      W_FSTR93       1243 - 1253
      W_FSTR94       1254 - 1264
      W_FSTR95       1265 - 1275
      W_FSTR96       1276 - 1286
      W_FSTR97       1287 - 1297
      W_FSTR98       1298 - 1308
      W_FSTR99       1309 - 1319
      W_FSTR100      1320 - 1330
 ;


 LABEL
      NACIONAL        = "Variable auxiliar para obtener promedios nacionales"
      ESCUELA         = "Identificador de la escuela"
      ID_ENT          = "Entidad federativa (identificador numrico)"
      NOM_ENT         = "Entidad federativa"
      ID_MOD          = "Estrato escolar o Modalidad educativa (identificador numrico)"
      MOD             = "Estrato escolar o Modalidad educativa"
      ESTRATO         = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
      ENTEST          = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
      ALUMNO          = "Identificador del alumno"
      ID_INSTR        = "Identificador del cuadernillo de examen"
      SEXO            = "Sexo del alumno"
      EDAD_AC         = "Edad en aos cumplidos (al momento de la aplicacin)"
      MES_NAC         = "Mes de nacimiento del alumno"
      EDAD            = "Edad del alumno al mes de mayo de 2014, en aos (al momento de la aplicacin). Incluye los meses cumplidos (decimales)"
      EDAD_ACC        = "Edad en aos cumplidos codificada (con recodificacin y colapsamiento de categoras de la variable EDAD_AC)"
      EDAD_N          = "Edad normativa. Supone el ingreso al primero de primaria con 6 aos cumplidos (o menos) al primero de septiembre"
      EDAD_ANT        = "Edad anticipada. Variable indicadora de los alumnos que ingresaron al primero de primaria con menos de 6 aos cumplidos al primero de septiembre"
      EDAD_EES        = "Extra edad severa. Variable indicadora de los alumnos que tienen dos aos o ms de retraso en el sistema escolar"
      W_ALU           = "Peso muestral o ponderador del alumno"
      DOCENTE         = "Identificador del docente que imparte clases al alumno"
      PMA_01	      = "Identificar cmo se nombra un nmero escrito con cifras sin ceros intermedios."
      PMA_02	      = "Resolver problemas que implican la relacin de la mitad de un nmero."
      PMA_03	      = "Sumar nmeros naturales de tres cifras con transformacin."
      PMA_04	      = "Reconocer la operacin de suma que resuelve un problema aditivo."
      PMA_05	      = "Identificar la resta que resuelve un problema aditivo."
      PMA_06	      = "Resolver problemas aditivos que incluyan dos operaciones combinadas, con base en la informacin dada explcitamente en un portador."
      PMA_07	      = "Resolver problemas de multiplicacin con datos dados en un cartel."
      PMA_08	      = "Resolver problemas de reparto que involucren una divisin sin el apoyo de una ilustracin."
      PMA_09	      = "Identificar fracciones equivalentes mayores que la unidad."
      PMA_10	      = "Resolver problemas de reparto cuya solucin implique un cociente con informacin dada en portadores."
      PMA_11	      = "Identificar la ubicacin de un objeto por su longitud en un conjunto ordenado de objetos."
      PMA_13	      = "Reconocer longitudes o distancias que es conveniente medir en metros."
      PMB_01	      = "Resolver problemas de reparto cuyo resultado sea una fraccin impropia."
      PMB_02	      = "Identificar nmeros no consecutivos en una sucesin decreciente con progresin aritmtica."
      PMB_03	      = "Resolver problemas aditivos de combinacin que implique reunir dos conjuntos y la incgnita es el resultado."
      PMB_04	      = "Resolver problemas aditivos de cambio en los que la incgnita es el operador."
      PMB_05	      = "Resolver problemas aditivos de comparacin donde la incgnita es la cantidad mayor."
      PMB_06	      = "Resolver problemas de comparacin donde la incgnita es la diferencia."
      PMB_07	      = "Resolver una multiplicacin de un mltiplo de 10 menor que 100 por un nmero de una cifra."
      PMB_08	      = "Resolver problemas de agrupamiento con datos en un cartel cuya solucin implique una divisin."
      PMB_09	      = "Identificar figuras no consecutivas que completan una sucesin creciente con progresin aritmtica."
      PMB_10	      = "Resolver problemas de agrupamiento con divisores menores que 10, usando una ilustracin, cuya solucin implique una divisin."
      PMB_11	      = "Resolver problemas que impliquen calcular la hora en que finaliza una actividad, dada la hora de inicio y la duracin de  la misma."
      PMB_13	      = "Resolver un problema en donde se calcula la hora en que finaliza una actividad, a partir de la hora marcada en un reloj de manecillas."
      PMC_01	      = "Ordenar de mayor a menor nmeros naturales de cuatro cifras."
      PMC_02	      = "Identificar cmo se nombran, los nmeros escritos con cuatro cifras con ceros intermedios."
      PMC_04	      = "Resolver problemas de transformacin con la incgnita en el estado final."
      PMC_05	      = "Resolver problemas aditivos de comparacin en los que la incgnita es la cantidad menor."
      PMC_06	      = "Resolucin de problemas aditivos de igualacin donde la incgnita sea la diferencia."
      PMC_07	      = "Resolver problemas de reparto que involucren una divisin con el apoyo de una ilustracin."
      PMC_08	      = "Restar nmeros naturales de tres cifras con transformacin y ceros en el minuendo."
      PMC_09	      = "Resolver problemas que implican multiplicar un nmero de dos cifras por uno de una, con transformacin."
      PMC_10	      = "Reconocer la divisin como la operacin que puede resolver un problema multiplicativo."
      PMC_11	      = "Resolver problemas que implican calcular la duracin de una actividad, a partir de la hora marcada en un reloj de manecillas."
      PMC_12	      = "Comparar las longitudes de distintos objetos."
      PMC_13	      = "Identificar las caractersticas de una figura geomtrica dada su imagen."
      PMD_01	      = "Identificar cmo se escriben un nmero de cuatro cifras sin ceros intermedios dado su nombre con letra."
      PMD_02	      = "Identificar fracciones equivalentes menores que la unidad."
      PMD_03	      = "Resolver problemas aditivos de cambio donde la incgnita es la cantidad inicial."
      PMD_04	      = "Identificar  tres nmeros consecutivos que continan en una sucesin decreciente con progresin aritmtica."
      PMD_05	      = "Resolver problemas aditivos de cambio en los que la incgnita est en el operador."
      PMD_06	      = "Sumar nmeros naturales de tres cifras sin transformacin."
      PMD_07	      = "Resolver problemas aditivos que implican tres operaciones a partir de informacin dada en portadores."
      PMD_08	      = "Identificar las figuras que continan una sucesin creciente con progresin aritmtica."
      PMD_09	      = "Resolver problemas de multiplicacin con factores de un dgito."
      PMD_10	      = "Identificar la suma iterada que resuelve un problema multiplicativo."
      PMD_11	      = "Multiplicar dos nmeros de una cifra."
      PMD_13	      = "Resolver problemas que impliquen calcular la duracin de una actividad dada la hora de inicio y de trmino."
      PMD_14	      = "Ordenar de menor a mayor tres objetos por su longitud."
      PME_01	      = "Resolver problemas de reparto cuyo resultado sea una fraccin propia."
      PME_02	      = "Identificar tres nmeros consecutivos que continan en una sucesin creciente con progresin aritmtica."
      PME_03	      = "Identificar dos nmeros no consecutivos en una sucesin creciente con progresin aritmtica."
      PME_04	      = "Resolver problemas aditivos de combinacin donde la incgnita es uno de los sumandos."
      PME_05	      = "Resolver problemas aditivos de cambio en los que la incgnita es el estado final."
      PME_06	      = "Restar nmeros naturales de tres cifras sin transformacin con ceros en el sustraendo."
      PME_07	      = "Restar nmeros naturales de tres cifras con transformacin y sin ceros en el minuendo."
      PME_08	      = "Resolver problemas de multiplicacin con factores de dos cifras por uno de una, sin transformacin."
      PME_10	      = "Reconocer una composicin formada por figuras geomtricas idntica a otra."
      PME_11	      = "Resolver un problema de agrupamiento que implique una divisin sin apoyo de una ilustracin."
      PME_13	      = "Identificar un tringulo dadas sus caractersticas geomtricas tales como nmero, tamao y forma de lados."
      PMF_01	      = "Identificar cmo se escribe con cifras un nmero de cuatro cifras con cero intermedio, dado su nombre con letra."
      PMF_02	      = "Comparar nmeros naturales de cuatro cifras."
      PMF_04	      = "Resolver problemas aditivos de cambio con la incgnita en el estado inicial."
      PMF_05	      = "Resolver problemas aditivos de igualacin donde  la incgnita es la cantidad mayor."
      PMF_06	      = "Resolver problemas aditivos de igualacin donde la incgnita es la cantidad menor."
      PMF_07	      = "Identificar la operacin de multiplicacin que permite resolver un problema."
      PMF_09	      = "Calcular el factor de una multiplicacin cuando se da el resultado del producto y el otro factor."
      PMF_10	      = "Identificar la hora marcada en un reloj de manecillas."
      PMF_11	      = "Resolver problemas que impliquen calcular la hora de inicio de una actividad dada la hora de trmino en un reloj de manecillas."
      PMF_12	      = "Resolver problemas en los que se calcula la hora de inicio de una actividad, dada la hora de termino y la duracin de la misma."
      PMF_13	      = "Resolver problemas en los que se use la regla graduada para medir objetos en centmetros."
      PV1MAT          = "Primer valor plausible de Matemticas"
      PV2MAT          = "Segundo valor plausible de Matemticas"
      PV3MAT          = "Tercer valor plausible de Matemticas"
      PV4MAT          = "Cuarto valor plausible de Matemticas"
      PV5MAT          = "Quinto valor plausible de Matemticas"
      MATNVL1         = "Nivel de logro en Matemticas. Asociado a PV1MAT. (Cuatro niveles)"
      MATNVL2         = "Nivel de logro en Matemticas. Asociado a PV2MAT. (Cuatro niveles)"
      MATNVL3         = "Nivel de logro en Matemticas. Asociado a PV3MAT. (Cuatro niveles)"
      MATNVL4         = "Nivel de logro en Matemticas. Asociado a PV4MAT. (Cuatro niveles)"
      MATNVL5         = "Nivel de logro en Matemticas. Asociado a PV5MAT. (Cuatro niveles)"
      MATNVBL1        = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV1MAT."
      MATNVBL2        = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV2MAT."
      MATNVBL3        = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV3MAT."
      MATNVBL4        = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV4MAT."
      MATNVBL5        = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV5MAT."
      MATNVML1        = "Identifica si el alumno pertenece al menos al nivel medio de logro en Matemticas. Asociado a PV1MAT."
      MATNVML2        = "Identifica si el alumno pertenece al menos al nivel medio de logro en Matemticas. Asociado a PV2MAT."
      MATNVML3        = "Identifica si el alumno pertenece al menos al nivel medio de logro en Matemticas. Asociado a PV3MAT."
      MATNVML4        = "Identifica si el alumno pertenece al menos al nivel medio de logro en Matemticas. Asociado a PV4MAT."
      MATNVML5        = "Identifica si el alumno pertenece al menos al nivel medio de logro en Matemticas. Asociado a PV5MAT."
      WVARSTRR        = "Identificador del pseudoestrato (1 a 100) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
      W_FSTR1         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR2         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR3         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR4         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR5         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR6         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR7         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR8         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR9         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR10        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR11        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR12        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR13        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR14        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR15        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR16        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR17        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR18        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR19        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR20        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR21        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR22        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR23        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR24        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR25        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR26        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR27        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR28        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR29        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR30        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR31        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR32        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR33        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR34        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR35        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR36        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR37        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR38        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR39        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR40        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR41        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR42        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR43        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR44        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR45        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR46        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR47        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR48        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR49        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR50        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR51        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR52        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR53        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR54        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR55        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR56        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR57        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR58        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR59        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR60        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR61        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR62        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR63        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR64        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR65        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR66        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR67        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR68        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR69        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR70        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR71        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR72        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR73        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR74        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR75        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR76        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR77        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR78        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR79        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR80        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR81        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR82        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR83        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR84        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR85        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR86        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR87        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR88        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR89        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR90        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR91        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR92        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR93        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR94        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR95        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR96        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR97        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR98        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR99        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR100       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
;


 FORMAT
      NACIONAL          1.
      ESCUELA           4.
      ID_ENT            id_entF.
      NOM_ENT           $char19.
      ID_MOD            id_modF.
      MOD               $modF.
      ESTRATO           $char7.
      ENTEST            $entestF.
      ALUMNO            5.
      ID_INSTR          $char15.
      SEXO              sexoF.
      EDAD_AC           edad_acF.
      MES_NAC           mes_nacF.
      EDAD              edadF.
      EDAD_ACC          edadCF.
      EDAD_N            edadNF.
      EDAD_ANT          edadAF.
      EDAD_EES          edadEF.
      DOCENTE           docenF.
      PMA_01            reactF.
      PMA_02            reactF.
      PMA_03            reactF.
      PMA_04            reactF.
      PMA_05            reactF.
      PMA_06            reactF.
      PMA_07            reactF.
      PMA_08            reactF.
      PMA_09            reactF.
      PMA_10            reactF.
      PMA_11            reactF.
      PMA_13            reactF.
      PMB_01            reactF.
      PMB_02            reactF.
      PMB_03            reactF.
      PMB_04            reactF.
      PMB_05            reactF.
      PMB_06            reactF.
      PMB_07            reactF.
      PMB_08            reactF.
      PMB_09            reactF.
      PMB_10            reactF.
      PMB_11            reactF.
      PMB_13            reactF.
      PMC_01            reactF.
      PMC_02            reactF.
      PMC_04            reactF.
      PMC_05            reactF.
      PMC_06            reactF.
      PMC_07            reactF.
      PMC_08            reactF.
      PMC_09            reactF.
      PMC_10            reactF.
      PMC_11            reactF.
      PMC_12            reactF.
      PMC_13            reactF.
      PMD_01            reactF.
      PMD_02            reactF.
      PMD_03            reactF.
      PMD_04            reactF.
      PMD_05            reactF.
      PMD_06            reactF.
      PMD_07            reactF.
      PMD_08            reactF.
      PMD_09            reactF.
      PMD_10            reactF.
      PMD_11            reactF.
      PMD_13            reactF.
      PMD_14            reactF.
      PME_01            reactF.
      PME_02            reactF.
      PME_03            reactF.
      PME_04            reactF.
      PME_05            reactF.
      PME_06            reactF.
      PME_07            reactF.
      PME_08            reactF.
      PME_10            reactF.
      PME_11            reactF.
      PME_13            reactF.
      PMF_01            reactF.
      PMF_02            reactF.
      PMF_04            reactF.
      PMF_05            reactF.
      PMF_06            reactF.
      PMF_07            reactF.
      PMF_09            reactF.
      PMF_10            reactF.
      PMF_11            reactF.
      PMF_12            reactF.
      PMF_13            reactF.
      MATNVL1           nvlF.
      MATNVL2           nvlF.
      MATNVL3           nvlF.
      MATNVL4           nvlF.
      MATNVL5           nvlF.
      MATNVBL1          nvblF.
      MATNVBL2          nvblF.
      MATNVBL3          nvblF.
      MATNVBL4          nvblF.
      MATNVBL5          nvblF.
      MATNVML1          nvmlF.
      MATNVML2          nvmlF.
      MATNVML3          nvmlF.
      MATNVML4          nvmlF.
      MATNVML5          nvmlF.
      WVARSTRR          3.
;



/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
 IF  SEXO = 8 THEN  SEXO = .M;
 IF  EDAD_AC = 98 THEN  EDAD_AC = .M;
 IF  MES_NAC = 98 THEN  MES_NAC = .M;
 IF  ENTEST = "999" THEN  ENTEST = .S;
 IF  DOCENTE = 99999 THEN  DOCENTE = .S;

 ARRAY perdidos1(5)  SEXO EDAD_ACC EDAD_N EDAD_ANT EDAD_ANT;
 DO  i=1 TO 5;
       IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
 END;

 ARRAY perdidos2(3)  EDAD EDAD_AC MES_NAC;
 DO  i=1 TO 3;
       IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
 END;


 ARRAY perdidos3(71)
             PMA_01 PMA_02 PMA_03 PMA_04 PMA_05 PMA_06 PMA_07 PMA_08 PMA_09 PMA_10 PMA_11 PMA_13 PMB_01 PMB_02 PMB_03 PMB_04 PMB_05 PMB_06
             PMB_07 PMB_08 PMB_09 PMB_10 PMB_11 PMB_13 PMC_01 PMC_02 PMC_04 PMC_05 PMC_06 PMC_07 PMC_08 PMC_09 PMC_10 PMC_11 PMC_12 PMC_13
             PMD_01 PMD_02 PMD_03 PMD_04 PMD_05 PMD_06 PMD_07 PMD_08 PMD_09 PMD_10 PMD_11 PMD_13 PMD_14 PME_01 PME_02 PME_03 PME_04 PME_05
             PME_06 PME_07 PME_08 PME_10 PME_11 PME_13 PMF_01 PMF_02 PMF_04 PMF_05 PMF_06 PMF_07 PMF_09 PMF_10 PMF_11 PMF_12 PMF_13;
 DO  i=1 TO 71;
        IF perdidos3{i} = 5   THEN  perdidos3{i} = .N;
        IF perdidos3{i} = 6   THEN  perdidos3{i} = .N;
        IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
        IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
        IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
 END;

 drop i;
RUN;

